==> tine20-allinone_2020.03.4.tar.bz2: Setup/js/Setup-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Eu li o contrato de licenciamento e aceito"

, "License Agreement"
: "Contrato de Licenciamento"

, "I have read the privacy agreement and accept it"
: "Eu li o acordo de privacidade e aceito"

, "Privacy Agreement"
: "Acordo de Privacidade"

, "Accept Terms and Conditions"
: "Aceitar Termos e Condições"

, "Backend"
: "Retaguarda"

, "Standard IMAP"
: "IMAP Básico"

, "Standard SMTP"
: "SMTP Básico"

, "Imap"
: "IMAP"

, "Hostname"
: "Servidor"

, "Username"
: "Nome do usuário"

, "Password"
: "Senha"

, "Port"
: "Porta"

, "Secure Connection"
: "Conexão Segura"

, "None"
: "Nenhum"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Usar a conta do sistema"

, "No"
: "Não"

, "Yes"
: "Sim"

, "Append domain to login name"
: "Adicionar domínio ao nome de entrada"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Administrador Cyrus"

, "Cyrus Admin Password"
: "Senha do Administrador Cyrus"

, "Use proxy auth"
: ""

, "Smtp"
: "SMTP"

, "Authentication"
: "Autenticação"

, "Login"
: "Entrar"

, "Plain"
: "Plano"

, "Primary Domain"
: "Domínio Principal"

, "Secondary Domains (comma separated)"
: "Domínio Secundário (separado por vírgula)"

, "Notifications service address"
: "Endereço do Serviço de Notificações"

, "Notification Username"
: "Usuário de Notificação"

, "Notification Password"
: "Senha de Notificação"

, "Notifications local client (hostname or IP address)"
: "Notificação para cliente local (servidor ou endereço IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Servidor MySql"

, "MySql Database"
: "Banco de Dados MySql"

, "MySql User"
: "Usuário MySql"

, "MySql Password"
: "Senha do MySql"

, "MySql Port"
: "Porta MySql"

, "User or UID"
: "Usuário ou UID"

, "Group or GID"
: "Grupo ou GID"

, "Home Template"
: "Modelo Inicial"

, "Password Scheme"
: "Esquema de Senha"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLANO"

, "Terms and Conditions"
: "Termos e Condições"

, "Setup Checks"
: "Verificações de Configuração"

, "Config Manager"
: "Gerenciador de Configuração"

, "Authentication/Accounts"
: "Autenticação/Contas"

, "Email"
: "Email"

, "Application Manager"
: "Gerenciador de Aplicação"

, "Setup"
: ""

, "Name"
: "Nome"

, "Enabled"
: "Permitido"

, "Order"
: "Ordenar"

, "Installed Version"
: "Versão Instalada"

, "Available Version"
: "Versão Disponível"

, "Status"
: "Situação"

, "Depends on"
: "Depende de"

, "Install application"
: "Instalar aplicação"

, "Uninstall application"
: "Desinstalar aplicação"

, "Update application"
: "Atualizar aplicação"

, "Go to {0} login"
: "Ir para {0} entrar"

, "uninstall"
: "desinstalar"

, "Do you really want to uninstall the application(s)?"
: "Você quer realmente desinstalar a aplicação(ões)?"

, "This may take a while"
: "Isso pode demorar um pouco"

, "Dependency Violation"
: "Violação de Dependência1"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Apague todos os usuários e grupos que existam"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Alterando de SQL para LDAP todos as Contas de Usuários, Grupos e Funções serão apagadas. Você quer realmente trocar a copnta de armazenamento para LDAP ?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Usuário Administrador Inicial"

, "Initial admin login name"
: "nome de entrada do administrador inicial"

, "Initial admin Password"
: "Senha do administrador principal"

, "Password confirmation"
: "Confirmação da Senha"

, "Authentication provider"
: "Fornecedor de Autenticação"

, "Try to split username"
: "Tente dividir o nome do usuário"

, "Account canonical form"
: "Formulário da conta canônica"

, "Account domain name"
: ""

, "Account domain short name"
: "Nome curto do domínio da conta"

, "Host"
: "Hospedeiro"

, "Login name"
: "Nome de entrada"

, "Bind requires DN"
: "Ligação requer DN"

, "Start TLS"
: ""

, "Base DN"
: "Base DN"

, "Search filter"
: "Filtro de pesquisa"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Armazenamento de contas"

, "Default user group name"
: "Nome básico do grupo usuário"

, "Default admin group name"
: "Nome do grupo padrão de administrador"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Definições de Senha"

, "User can change password"
: "Usuário pode modificar a senha"

, "Enable password policy"
: "Permitir política de senha"

, "Only ASCII"
: "Somente ASCII"

, "Minimum length"
: "Tamanho mínimo"

, "Minimum word chars"
: "Mínimo de caracteres por palavra"

, "Minimum uppercase chars"
: "Caracteres maiúsculos mínimos"

, "Minimum special chars"
: "Caracteres especiais mínimos"

, "Minimum numbers"
: "Números mínimos"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Não é permitido usar parte do nome do usuário na senha"

, "Redirect Settings"
: "Redirecionar Definições"

, "Redirect Url (redirect to login screen if empty)"
: "Redirecionar Url (se estiver vazio, redirecionar para a tela de entrada)"

, "Redirect Always (if No, only redirect after logout)"
: "Redirecionar Sempre (se Não, redirecionar somente após sair)"

, "Redirect to referring site, if exists"
: "Redirecionar para o site de referência, se existir"

, "Password encoding"
: "Codificando a Senha"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Usuário DN"

, "User Filter"
: "Filtro de Usuário"

, "User Search Scope"
: "Escopo da Pesquisa de Usuário"

, "Groups DN"
: "Grupos DN"

, "Group Filter"
: "Filtro de Grupo"

, "Group Search Scope"
: "Escopo da Pesquisa de Grupo"

, "Use Rfc 2307 bis"
: "Usar Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Id do Usuário Min"

, "Max User Id"
: "Id do Usuário Max"

, "Min Group Id"
: "ID do Grupo Mínimo"

, "Max Group Id"
: "ID do Grupo Máximo"

, "Group UUID Attribute name"
: "Nome do Atributo do Grupo UUID"

, "User UUID Attribute name"
: "Nome do Atributo do Usuário UUID"

, "Readonly access"
: "Acesso somente para leitura"

, "Save config and install"
: "Salvar configuração e instalar"

, "Save config"
: "Salvar configuração"

, "Passwords don't match"
: "Senhas são diferentes"

, "Should not be empty"
: "Não deveria estar vazio"

, "Performing Environment Checks..."
: "Executar Verificações de Ambiente..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Não pode ser encontrado qualquer {0}.  Favor alterar seu critério de pesquisa, ver opções ou o {1} que você pesquisa em."

, "Check"
: "Verificar"

, "Result"
: "Resultar"

, "Error"
: "Erro"

, "Run setup tests"
: "Executar testes de configurações"

, "Ignore setup tests"
: "Ignorar testes de configurações"

, "Application, Applications"
: [
  "Aplicação"
 ,"Aplicações"

]
, "File"
: "Arquivo"

, "Setup Authentication"
: "Autenticação da Configuração"

, "Database"
: "Banco de dados"

, "User"
: "Usuário"

, "Prefix"
: "Prefixo"

, "Logging"
: "Entrando"

, "Filename"
: "Nome do arquivo"

, "Priority"
: "Prioridade"

, "Caching"
: "Colocando na memória"

, "Lifetime (seconds)"
: "Ciclo de vida (segundos)"

, "Path"
: "Caminho"

, "Queue"
: "Fila"

, "Session"
: "Sessão"

, "Temporary files"
: "Arquivos temporários"

, "Temporary Files Path"
: "Caminho dos Arquivos Temporários"

, "Filestore directory"
: "Diretório de armazenamento de arquivos"

, "Filestore Path"
: "Caminho do armazenamento de arquivos"

, "Addressbook Map panel"
: "Catálogo de endereços do Painel Map"

, "Map panel"
: "Painel Map"

, "disabled"
: "inválido"

, "enabled"
: "permitido"

, "Config file is not writable"
: "Arquivo de configuração somente para leitura"

, "Download config file"
: "Baixando arquivo de configuração"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Aplicação"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Setup/js/Setup-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: "Executar Verificações de Ambiente..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Não pode ser encontrado qualquer {0}.  Favor alterar seu critério de pesquisa, ver opções ou o {1} que você pesquisa em."

, "Check"
: "Verificar"

, "Result"
: "Resultar"

, "Message"
: ""

, "Run setup tests"
: "Executar testes de configurações"

, "Ignore setup tests"
: "Ignorar testes de configurações"

, "Install application"
: "Instalar aplicação"

, "Name"
: "Nome"

, "Enabled"
: "Permitido"

, "Order"
: "Ordenar"

, "Installed Version"
: "Versão Instalada"

, "Available Version"
: "Versão Disponível"

, "Status"
: "Situação"

, "Depends on"
: "Depende de"

, "Uninstall application"
: "Desinstalar aplicação"

, "Update applications"
: ""

, "Go to {0} login"
: "Ir para {0} entrar"

, "uninstall"
: "desinstalar"

, "Do you really want to uninstall the application(s)?"
: "Você quer realmente desinstalar a aplicação(ões)?"

, "This may take a while"
: "Isso pode demorar um pouco"

, "Dependency Violation"
: "Violação de Dependência1"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Apague todos os usuários e grupos que existam"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Alterando de SQL para LDAP todos as Contas de Usuários, Grupos e Funções serão apagadas. Você quer realmente trocar a copnta de armazenamento para LDAP ?"

, "Backend"
: "Retaguarda"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Usuário Administrador Inicial"

, "Initial admin login name"
: "nome de entrada do administrador inicial"

, "Initial admin Password"
: "Senha do administrador principal"

, "Password confirmation"
: "Confirmação da Senha"

, "Authentication provider"
: "Fornecedor de Autenticação"

, "Try to split username"
: "Tente dividir o nome do usuário"

, "Yes"
: "Sim"

, "No"
: "Não"

, "Account canonical form"
: "Formulário da conta canônica"

, "Account domain name"
: ""

, "Account domain short name"
: "Nome curto do domínio da conta"

, "Host"
: "Hospedeiro"

, "Login name"
: "Nome de entrada"

, "Password"
: "Senha"

, "Bind requires DN"
: "Ligação requer DN"

, "Start TLS"
: ""

, "SSL"
: "SSL"

, "Port"
: "Porta"

, "Base DN"
: "Base DN"

, "Search filter"
: "Filtro de pesquisa"

, "Hostname"
: "Servidor"

, "Secure Connection"
: "Conexão Segura"

, "None"
: "Nenhum"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Adicionar domínio ao nome de entrada"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Armazenamento de contas"

, "Default user group name"
: "Nome básico do grupo usuário"

, "Default admin group name"
: "Nome do grupo padrão de administrador"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Definições de Senha"

, "User can change password"
: "Usuário pode modificar a senha"

, "Enable password policy"
: "Permitir política de senha"

, "Only ASCII"
: "Somente ASCII"

, "Minimum length"
: "Tamanho mínimo"

, "Minimum word chars"
: "Mínimo de caracteres por palavra"

, "Minimum uppercase chars"
: "Caracteres maiúsculos mínimos"

, "Minimum special chars"
: "Caracteres especiais mínimos"

, "Minimum numbers"
: "Números mínimos"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Não é permitido usar parte do nome do usuário na senha"

, "Redirect Settings"
: "Redirecionar Definições"

, "Redirect Url (redirect to login screen if empty)"
: "Redirecionar Url (se estiver vazio, redirecionar para a tela de entrada)"

, "Redirect Always (if No, only redirect after logout)"
: "Redirecionar Sempre (se Não, redirecionar somente após sair)"

, "Redirect to referring site, if exists"
: "Redirecionar para o site de referência, se existir"

, "Password encoding"
: "Codificando a Senha"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Usuário DN"

, "User Filter"
: "Filtro de Usuário"

, "User Search Scope"
: "Escopo da Pesquisa de Usuário"

, "Groups DN"
: "Grupos DN"

, "Group Filter"
: "Filtro de Grupo"

, "Group Search Scope"
: "Escopo da Pesquisa de Grupo"

, "Use Rfc 2307 bis"
: "Usar Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Id do Usuário Min"

, "Max User Id"
: "Id do Usuário Max"

, "Min Group Id"
: "ID do Grupo Mínimo"

, "Max Group Id"
: "ID do Grupo Máximo"

, "Group UUID Attribute name"
: "Nome do Atributo do Grupo UUID"

, "User UUID Attribute name"
: "Nome do Atributo do Usuário UUID"

, "Readonly access"
: "Acesso somente para leitura"

, "Save config and install"
: "Salvar configuração e instalar"

, "Save config"
: "Salvar configuração"

, "Passwords don't match"
: "Senhas são diferentes"

, "Should not be empty"
: "Não deveria estar vazio"

, "File"
: "Arquivo"

, "Setup Authentication"
: "Autenticação da Configuração"

, "Username"
: "Nome do usuário"

, "Database"
: "Banco de dados"

, "User"
: "Usuário"

, "Prefix"
: "Prefixo"

, "Logging"
: "Entrando"

, "Filename"
: "Nome do arquivo"

, "Priority"
: "Prioridade"

, "Caching"
: "Colocando na memória"

, "Lifetime (seconds)"
: "Ciclo de vida (segundos)"

, "Path"
: "Caminho"

, "Queue"
: "Fila"

, "Session"
: "Sessão"

, "Temporary files"
: "Arquivos temporários"

, "Temporary Files Path"
: "Caminho dos Arquivos Temporários"

, "Filestore directory"
: "Diretório de armazenamento de arquivos"

, "Filestore Path"
: "Caminho do armazenamento de arquivos"

, "Addressbook Map panel"
: "Catálogo de endereços do Painel Map"

, "Map panel"
: "Painel Map"

, "disabled"
: "inválido"

, "enabled"
: "permitido"

, "Config file is not writable"
: "Arquivo de configuração somente para leitura"

, "Download config file"
: "Baixando arquivo de configuração"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: "IMAP Básico"

, "Standard SMTP"
: "SMTP Básico"

, "Imap"
: "IMAP"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Usar a conta do sistema"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Administrador Cyrus"

, "Cyrus Admin Password"
: "Senha do Administrador Cyrus"

, "Use proxy auth"
: ""

, "Smtp"
: "SMTP"

, "Authentication"
: "Autenticação"

, "Login"
: "Entrar"

, "Plain"
: "Plano"

, "Primary Domain"
: "Domínio Principal"

, "Secondary Domains (comma separated)"
: "Domínio Secundário (separado por vírgula)"

, "Notifications service address"
: "Endereço do Serviço de Notificações"

, "Notification Username"
: "Usuário de Notificação"

, "Notification Password"
: "Senha de Notificação"

, "Notifications local client (hostname or IP address)"
: "Notificação para cliente local (servidor ou endereço IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Servidor MySql"

, "MySql Database"
: "Banco de Dados MySql"

, "MySql User"
: "Usuário MySql"

, "MySql Password"
: "Senha do MySql"

, "MySql Port"
: "Porta MySql"

, "User or UID"
: "Usuário ou UID"

, "Group or GID"
: "Grupo ou GID"

, "Home Template"
: "Modelo Inicial"

, "Password Scheme"
: "Esquema de Senha"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLANO"

, "Setup"
: ""

, "Application, Applications"
: [
  "Aplicação"
 ,"Aplicações"

]
, "Terms and Conditions"
: "Termos e Condições"

, "Setup Checks"
: "Verificações de Configuração"

, "Config Manager"
: "Gerenciador de Configuração"

, "Authentication/Accounts"
: "Autenticação/Contas"

, "Email"
: "Email"

, "Application Manager"
: "Gerenciador de Aplicação"

, "I have read the license agreement and accept it"
: "Eu li o contrato de licenciamento e aceito"

, "License Agreement"
: "Contrato de Licenciamento"

, "I have read the privacy agreement and accept it"
: "Eu li o acordo de privacidade e aceito"

, "Privacy Agreement"
: "Acordo de Privacidade"

, "Accept Terms and Conditions"
: "Aceitar Termos e Condições"


, "Application"
: "Aplicação"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
